package IO::Moose::IO_MooseTest_Bad;

0;
